@@ -31,6 +31,8 @@ class RayCluster:
     worker_mem_max: str
     worker_cpu: int
     worker_gpu: int
+    namespace: str
+    dashboard: str
 
 @dataclass
 class AppWrapper:
